@@ -1,5 +1,7 @@
 """
-Main interface for codebuild service literal definitions.
+Type annotations for codebuild service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/literals.html)
 
 Usage::
 
